@@ -4,7 +4,7 @@
  * Gnome Chemistry Utils
  * chemistry/xml-utils.cc 
  *
- * Copyright (C) 2002-2005 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2006 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -23,7 +23,11 @@
  */
 
 #include "xml-utils.h"
-#include <string.h>
+#include <cstring>
+#include <set>
+#include <string>
+
+using namespace std;
 
 xmlNodePtr FindNodeByNameAndId (xmlNodePtr node, const char* name, const char* id)
 {
@@ -169,7 +173,7 @@ bool ReadRadius (xmlNodePtr node, GcuAtomicRadius& radius)
 		xmlFree (tmp);
 	tmp = (char*) xmlGetProp (node, (xmlChar*) "scale");
 	if (tmp) {
-		radius.scale = g_strdup (tmp);
+		radius.scale = GetStaticScale (tmp);
 		xmlFree (tmp);
 	} else
 		radius.scale = NULL;
@@ -197,7 +201,7 @@ bool ReadRadius (xmlNodePtr node, GcuAtomicRadius& radius)
 		radius.value.value = strtod (tmp, &end);
 		dot = strchr (tmp, '.');
 		radius.value.prec = (dot)? end - dot - 1: 0;
-		radius.scale = g_strdup ("custom");
+		radius.scale = "custom";
 		xmlFree(tmp);
 	} else {
 		if (tmp)
@@ -226,19 +230,19 @@ bool WriteRadius (xmlDocPtr xml, xmlNodePtr node, const GcuAtomicRadius& radius)
 		tmp = NULL;
 		break;
 	case GCU_ATOMIC:
-		tmp = "atomic";
+		tmp = (char*) "atomic";
 		break;
 	case GCU_IONIC:
-		tmp = "ionic";
+		tmp = (char*) "ionic";
 		break;
 	case GCU_METALLIC:
-		tmp = "metallic";
+		tmp = (char*) "metallic";
 		break;
 	case GCU_COVALENT:
-		tmp = "covalent";
+		tmp = (char*) "covalent";
 		break;
 	case GCU_VAN_DER_WAALS:
-		tmp = "vdW";
+		tmp = (char*) "vdW";
 		break;
 	default:
 		tmp = NULL;
@@ -265,3 +269,19 @@ bool WriteRadius (xmlDocPtr xml, xmlNodePtr node, const GcuAtomicRadius& radius)
 		xmlNewProp (child, (xmlChar*) "spin", (xmlChar*)((radius.spin == GCU_LOW_SPIN)? "low": "high"));
 	return true;
 }
+
+// we must have static strings 
+static set <string> ScaleNames;
+
+char const *GetStaticScale (char *buf)
+{
+	set <string>::iterator i = ScaleNames.find (buf);
+	if (i == ScaleNames.end ()) {
+		std::pair<set <string>::iterator,bool> res = ScaleNames.insert (buf);
+		if (res.second)
+			return (*res.first).c_str ();
+		else
+			return NULL;
+	}
+	return (*i).c_str ();
+}
