@@ -4,7 +4,7 @@
  * Gnome Crystal
  * document.h 
  *
- * Copyright (C) 2000-2006 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2000-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -28,6 +28,7 @@
 #include <libxml/parser.h>
 #include <gcu/crystaldoc.h>
 #include <gcu/dialog.h>
+#include <gcu/macros.h>
 #include "atom.h"
 #include "line.h"
 #include "cleavage.h"
@@ -67,13 +68,10 @@ public:
 	void OnNewDocument();
 	void OnExportVRML (const string &FileName);
 	gcView* GetNewView();
-	bool IsEmpty() {return m_bEmpty;}
 	void AddView(gcView* pView);
 	bool RemoveView(gcView* pView);
 	void RemoveAllViews ();
 	bool VerifySaved();
-	void NotifyDialog(Dialog* dialog);
-	void RemoveDialog(Dialog* dialog);
 	bool GetFixedSize() {return m_bFixedSize;}
 	void SetFixedSize(bool FixedSize) {m_bFixedSize = FixedSize;}
 	virtual CrystalView* CreateNewView();
@@ -85,6 +83,8 @@ public:
 	void SaveAsImage (const string &filename, char const *type, map<string, string>& options);
 	gcView *GetActiveView () {return m_pActiveView;}
 	virtual bool LoadNewView (xmlNodePtr node);
+	list <CrystalView *> *GetViews () {return &m_Views;}
+	void RenameViews ();
 
 private:
 	void Error(int num);
@@ -96,6 +96,8 @@ private:
 	GtkWidget* m_widget;
 	std::list <Dialog *> m_Dialogs;
 	gcView *m_pActiveView;
+
+GCU_RO_PROP (bool, ReadOnly);
 };
 
 #endif //GCRYSTAL_DOCUMENT_H
