@@ -4,7 +4,7 @@
  * Gnome Crystal
  * view.h 
  *
- * Copyright (C) 2000-2006 Jean Brfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2000-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -31,6 +31,7 @@
 #include <gcu/crystalview.h>
 #include <gcu/matrix.h>
 #include <gcu/dialog.h>
+#include <gcu/dialog-owner.h>
 
 class gcDocument;
 class gcApplication;
@@ -38,35 +39,24 @@ class gcWindow;
 
 using namespace gcu;
 
-class gcView: public CrystalView
+class gcView: public CrystalView, public DialogOwner
 {
 public:
 	gcView (gcDocument *pDoc);
 	gcView (gcView *pView);
 	~gcView ();
 	
-	void SetDocument (gcDocument *pDoc);
-	gcDocument* GetDocument() {return (gcDocument *) m_pDoc;}
 	void SetBackgroundColor (float red, float green, float blue, float alpha);
 	void GetBackgroundColor (double *red, double *green, double *blue, double *alpha);
-	gdouble& GetFoV () {return m_fAngle;}
-	gdouble& GetPos () {return m_fRadius;}
+	gdouble& GetFoV () {return GetRefAngle ();}
+	gdouble& GetPos () {return m_Radius;}
 	void GetRotation (double *psi, double *theta, double *phi);
-	void SetRotation (double psi, double theta, double phi);
 	bool LoadOld (xmlNodePtr node);
-	void Print (GnomePrintContext *pc, gdouble width, gdouble height);
-	void SetLabel (GtkLabel* Label) {m_pLabel = Label;}
-	void SetMenu (GtkMenuItem* item);
-	GtkLabel* GetLabel () {return m_pLabel;}
-	GtkLabel* GetMenuLabel () {return m_pMenuLabel;}
-	void NotifyDialog (Dialog* dialog);
-	void RemoveDialog (Dialog* dialog);
 	gcWindow *GetWindow () {return m_Window;}
 	void SetWindow (gcWindow *window) {m_Window = window;}
 	
 private:
 
-	GtkLabel *m_pLabel, *m_pMenuLabel;
 	GtkMenuItem* m_pMenu;
 	std::list <Dialog *> m_Dialogs;
 	gcWindow *m_Window;
